@@ -14,7 +14,7 @@
     Copyright 2018-2024 Game Maker 2k - http://intdb.sourceforge.net/
     Copyright 2018-2024 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: foxfile.py - Last Update: 8/26/2025 Ver. 0.21.4 RC 1 - Author: cooldude2k $
+    $FileInfo: foxfile.py - Last Update: 11/3/2025 Ver. 0.24.4 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals, generators, with_statement, nested_scopes
@@ -91,57 +91,37 @@ __version_date_plusrc__ = pyfoxfile.__version_date_plusrc__
 __version__ = pyfoxfile.__version__
 
 # Initialize the argument parser
-argparser = argparse.ArgumentParser(
-    description="Manipulate archive files.", conflict_handler="resolve", add_help=True)
+argparser = argparse.ArgumentParser(description="Manipulate archive files.", conflict_handler="resolve", add_help=True)
 
 # Version information
-argparser.add_argument("-V", "--version", action="version",
-                       version=__program_name__ + " " + __version__)
+argparser.add_argument("-V", "--version", action="version", version=__program_name__ + " " + __version__)
 # Input and output specifications
-argparser.add_argument(
-    "-i", "--input", nargs="+", help="Specify the file(s) to concatenate or the archive file to extract.", required=True)
-argparser.add_argument("-o", "--output", default=None,
-                       help="Specify the name for the extracted or output archive files.")
+argparser.add_argument("-i", "--input", nargs="+", help="Specify the file(s) to concatenate or the archive file to extract.", required=True)
+argparser.add_argument("-o", "--output", default=None, help="Specify the name for the extracted or output archive files.")
 # Operations
-argparser.add_argument("-c", "--create", action="store_true",
-                       help="Perform only the concatenation operation.")
-argparser.add_argument("-e", "--extract", action="store_true",
-                       help="Perform only the extraction operation.")
-argparser.add_argument("-t", "--convert", action="store_true",
-                       help="Convert a tar/zip/rar/7zip file to a archive file.")
-argparser.add_argument("-r", "--repack", action="store_true",
-                       help="Re-concatenate files, fixing checksum errors if any.")
+argparser.add_argument("-c", "--create", action="store_true", help="Perform only the concatenation operation.")
+argparser.add_argument("-e", "--extract", action="store_true", help="Perform only the extraction operation.")
+argparser.add_argument("-t", "--convert", action="store_true", help="Convert a tar/zip/rar/7zip file to a archive file.")
+argparser.add_argument("-r", "--repack", action="store_true", help="Re-concatenate files, fixing checksum errors if any.")
+argparser.add_argument("-S", "--filestart", type=int, default=0, help="Start reading file at.")
 # File manipulation options
-argparser.add_argument(
-    "-F", "--format", default="auto", help="Specify the format to use.")
-argparser.add_argument(
-    "-D", "--delimiter", default=__file_format_dict__['format_delimiter'], help="Specify the delimiter to use.")
-argparser.add_argument(
-    "-m", "--formatver", default=__file_format_dict__['format_ver'], help="Specify the format version.")
-argparser.add_argument("-l", "--list", action="store_true",
-                       help="List files included in the archive file.")
+argparser.add_argument("-F", "--format", default="auto", help="Specify the format to use.")
+argparser.add_argument("-D", "--delimiter", default=__file_format_dict__['format_delimiter'], help="Specify the delimiter to use.")
+argparser.add_argument("-m", "--formatver", default=__file_format_dict__['format_ver'], help="Specify the format version.")
+argparser.add_argument("-l", "--list", action="store_true", help="List files included in the archive file.")
 # Compression options
-argparser.add_argument("-P", "--compression", default="auto",
-                       help="Specify the compression method to use for concatenation.")
-argparser.add_argument("-L", "--level", default=None,
-                       help="Specify the compression level for concatenation.")
-argparser.add_argument("-W", "--wholefile", action="store_true",
-                       help="Whole file compression method to use for concatenation.")
+argparser.add_argument("-P", "--compression", default="auto", help="Specify the compression method to use for concatenation.")
+argparser.add_argument("-L", "--level", default=None, help="Specify the compression level for concatenation.")
+argparser.add_argument("-W", "--wholefile", action="store_true", help="Whole file compression method to use for concatenation.")
 # Checksum and validation
-argparser.add_argument("-v", "--validate", action="store_true",
-                       help="Validate archive file checksums.")
-argparser.add_argument("-C", "--checksum", default="crc32",
-                       help="Specify the type of checksum to use. The default is crc32.")
-argparser.add_argument("-s", "--skipchecksum", action="store_true",
-                       help="Skip the checksum check of files.")
+argparser.add_argument("-v", "--validate", action="store_true", help="Validate archive file checksums.")
+argparser.add_argument("-C", "--checksum", default="crc32", help="Specify the type of checksum to use. The default is crc32.")
+argparser.add_argument("-s", "--skipchecksum", action="store_true", help="Skip the checksum check of files.")
 # Permissions and metadata
-argparser.add_argument("-p", "--preserve", action="store_false",
-                       help="Do not preserve permissions and timestamps of files.")
+argparser.add_argument("-p", "--preserve", action="store_false", help="Do not preserve permissions and timestamps of files.")
 # Miscellaneous
-argparser.add_argument("-d", "--verbose", action="store_true",
-                       help="Enable verbose mode to display various debugging information.")
-argparser.add_argument("-T", "--text", action="store_true",
-                       help="Read file locations from a text file.")
+argparser.add_argument("-d", "--verbose", action="store_true", help="Enable verbose mode to display various debugging information.")
+argparser.add_argument("-T", "--text", action="store_true", help="Read file locations from a text file.")
 # Parse the arguments
 getargs = argparser.parse_args()
 
@@ -173,7 +153,7 @@ if active_action:
             checkcompressfile = pyfoxfile.CheckCompressionSubType(
                 input_file, fnamedict, True)
             if((pyfoxfile.IsNestedDict(fnamedict) and checkcompressfile in fnamedict) or (pyfoxfile.IsSingleDict(fnamedict) and checkcompressfile==fnamedict['format_magic'])):
-                tmpout = pyfoxfile.RePackFoxFile(input_file, getargs.output, getargs.compression, getargs.wholefile, getargs.level, pyfoxfile.compressionlistalt, False, 0, 0, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], getargs.skipchecksum, [], {}, fnamedict, getargs.verbose, False)
+                tmpout = pyfoxfile.RePackFoxFile(input_file, getargs.output, getargs.compression, getargs.wholefile, getargs.level, pyfoxfile.compressionlistalt, False, getargs.filestart, 0, 0, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], getargs.skipchecksum, [], {}, fnamedict, getargs.verbose, False)
             else:
                 tmpout = pyfoxfile.PackFoxFileFromInFile(
                     input_file, getargs.output, __file_format_default__, getargs.compression, getargs.wholefile, getargs.level, pyfoxfile.compressionlistalt, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], [], {}, fnamedict, getargs.verbose, False)
@@ -187,56 +167,56 @@ if active_action:
                 input_file, fnamedict, True)
             if((pyfoxfile.IsNestedDict(fnamedict) and checkcompressfile in fnamedict) or (pyfoxfile.IsSingleDict(fnamedict) and checkcompressfile==fnamedict['format_magic'])):
                 pyfoxfile.RePackFoxFile(input_file, getargs.output, getargs.compression, getargs.wholefile, getargs.level, pyfoxfile.compressionlistalt,
-                                            False, 0, 0, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], getargs.skipchecksum, [], {}, fnamedict, getargs.verbose, False)
+                                            False, getargs.filestart, 0, 0, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], getargs.skipchecksum, [], {}, fnamedict, getargs.verbose, False)
             else:
                 pyfoxfile.PackFoxFileFromInFile(input_file, getargs.output, __file_format_default__, getargs.compression, getargs.wholefile, getargs.level, pyfoxfile.compressionlistalt, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], [], {}, fnamedict, getargs.verbose, False)
             if(not tmpout):
                 sys.exit(1)
         else:
             pyfoxfile.RePackFoxFile(input_file, getargs.output, getargs.compression, getargs.wholefile, getargs.level, pyfoxfile.compressionlistalt,
-                                        False, 0, 0, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], getargs.skipchecksum, [], {}, fnamedict, getargs.verbose, False)
+                                        False, getargs.filestart, 0, 0, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], getargs.skipchecksum, [], {}, fnamedict, getargs.verbose, False)
     elif active_action == 'extract':
         if getargs.convert:
             checkcompressfile = pyfoxfile.CheckCompressionSubType(
                 input_file, fnamedict, True)
             tempout = BytesIO()
             if((pyfoxfile.IsNestedDict(fnamedict) and checkcompressfile in fnamedict) or (pyfoxfile.IsSingleDict(fnamedict) and checkcompressfile==fnamedict['format_magic'])):
-                tmpout = pyfoxfile.RePackFoxFile(input_file, tempout, getargs.compression, getargs.wholefile, getargs.level, pyfoxfile.compressionlistalt, False, 0, 0, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], getargs.skipchecksum, [], {}, fnamedict, False, False)
+                tmpout = pyfoxfile.RePackFoxFile(input_file, tempout, getargs.compression, getargs.wholefile, getargs.level, pyfoxfile.compressionlistalt, False, getargs.filestart, 0, 0, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], getargs.skipchecksum, [], {}, fnamedict, False, False)
             else:
                 tmpout = pyfoxfile.PackFoxFileFromInFile(
                     input_file, tempout, __file_format_default__, getargs.compression, getargs.wholefile, getargs.level, pyfoxfile.compressionlistalt, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], [], {}, fnamedict, False, False)
             if(not tmpout):
                 sys.exit(1)
             input_file = tempout
-        pyfoxfile.UnPackFoxFile(input_file, getargs.output, False, 0, 0, getargs.skipchecksum,
+        pyfoxfile.UnPackFoxFile(input_file, getargs.output, False, getargs.filestart, 0, 0, getargs.skipchecksum,
                                     fnamedict, getargs.verbose, getargs.preserve, getargs.preserve, False, False)
     elif active_action == 'list':
         if getargs.convert:
             checkcompressfile = pyfoxfile.CheckCompressionSubType(
                 input_file, fnamedict, True)
             if((pyfoxfile.IsNestedDict(fnamedict) and checkcompressfile in fnamedict) or (pyfoxfile.IsSingleDict(fnamedict) and checkcompressfile==fnamedict['format_magic'])):
-                tmpout = pyfoxfile.FoxFileListFiles(input_file, "auto", 0, 0, getargs.skipchecksum, fnamedict, False, getargs.verbose, False, False)
+                tmpout = pyfoxfile.FoxFileListFiles(input_file, "auto", getargs.filestart, 0, 0, getargs.skipchecksum, fnamedict, False, getargs.verbose, False, False)
             else:
                 tmpout = pyfoxfile.InFileListFiles(input_file, getargs.verbose, fnamedict, False, False, False)
             if(not tmpout):
                 sys.exit(1)
         else:
-            pyfoxfile.FoxFileListFiles(input_file, "auto", 0, 0, getargs.skipchecksum, fnamedict, False, getargs.verbose, False, False)
+            pyfoxfile.FoxFileListFiles(input_file, "auto", getargs.filestart, 0, 0, getargs.skipchecksum, fnamedict, False, getargs.verbose, False, False)
     elif active_action == 'validate':
         if getargs.convert:
             checkcompressfile = pyfoxfile.CheckCompressionSubType(
                 input_file, fnamedict, True)
             tempout = BytesIO()
             if((pyfoxfile.IsNestedDict(fnamedict) and checkcompressfile in fnamedict) or (pyfoxfile.IsSingleDict(fnamedict) and checkcompressfile==fnamedict['format_magic'])):
-                tmpout = pyfoxfile.RePackFoxFile(input_file, tempout, getargs.compression, getargs.wholefile, getargs.level, pyfoxfile.compressionlistalt, False, 0, 0, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], getargs.skipchecksum, [], {}, fnamedict, False, False, False)
+                tmpout = pyfoxfile.RePackFoxFile(input_file, tempout, getargs.compression, getargs.wholefile, getargs.level, pyfoxfile.compressionlistalt, False, getargs.filestart, 0, 0, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], getargs.skipchecksum, [], {}, fnamedict, False, False, False)
             else:
                 tmpout = pyfoxfile.PackFoxFileFromInFile(
                     input_file, tempout, __file_format_default__, getargs.compression, getargs.wholefile, getargs.level, pyfoxfile.compressionlistalt, [getargs.checksum, getargs.checksum, getargs.checksum, getargs.checksum], [], {}, fnamedict, False, False)
             input_file = tempout
             if(not tmpout):
                 sys.exit(1)
-        fvalid = pyfoxfile.FoxFileValidate(
-            input_file, "auto", fnamedict, False, getargs.verbose, False)
+        fvalid = pyfoxfile.StackedFoxFileValidate(
+            input_file, "auto", getargs.filestart, fnamedict, False, getargs.verbose, False)
         if(not getargs.verbose):
             import sys
             import logging
